#
# net.rb
#
#   Copyright (c) 2001 Minero Aoki <aamine@loveruby.net>
#
#   This program is free software.
#   you can distribute/modify this program under the terms of
#   the GNU General Public License version 2 or later.
#

require 'net/smtp'
require 'net/pop'


module Delta

  class SMTPClient

    def initialize( client, helo, moveto,
                    cmsgid = true, cdate = true )
      @client = client
@client.set_debug_output $stderr
      @helo = helo
      @moveto = moveto

      @create_msgid = cmsgid
      @create_date = cdate
    end

    def connect
      unless @client.started? then
        @client.start(@helo) {
            yield self
        }
      else
        yield self
      end
    end

    def send_mail_from( src_mbox, port, m = nil )
      m ||= TMail::Mail.new(port)
      from, = m.from_addrs
      to = m.destinations

      %w( bcc received ).each do |field|
        m.delete field
      end
      m.message_id = TMail.new_message_id if @create_msgid
      m.date = Time.now if @create_date

      connect {
          @client.ready( from, to ) {|f|
              m.encoded f
          }
      }

      post_send src_mbox, port
    end

    private

    def post_send( src, port )
      src_mbox.move_to @moveto, port if @moveto
    end
  
  end


  class POPClient

    def initialize( client, account, password, dest_mbox )
      @client = client
      @account = account
      @password = password
      @dest = dest_mbox
    end

    def pop
      @client.start(@account, @password) {|pop|
          # pop.delete_all do |m|
          pop.each do |m|
            @dest.new {|port|
                port.ropen {|f| m.pop f }
            }
          end
      }
    end

  end

end
